==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-italian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pagina Precedente");
define("_NEXT","Prossima Pagina");
define("_SEARCHRESULTS","Risultati Ricerca");
define("_PAGE","Pagina");
define("_RETURNTO","Ritorna a");
define("_DEACTIVATE","Disattiva");
define("_ACTIVATE","Attiva");
define("_ENCYCLOPEDIA","Enciclopedia");
define("_NOCONTENTFORLETTER","Non ci sono occorrenze per la lettera");
define("_ENCYSELECTLETTER","Seleziona una lettera da questa lista per consultare i termini:");
define("_COPYRIGHT","Copyright &copy; by $sitename. Tutti i diritti riseervati.");
define("_YOURADMINENCY","Sei l'amministratore, questa Enciclopedia non &egrave; attiva!");
define("_ENCYNOTACTIVE","Spiacente, questa enciclopedia non &egrave; attiva al momento.");
define("_AVAILABLEENCYLIST","Lista delle Enciclopedie disponibili in");
define("_YOURADMININACTIVELIST","Sei l'amministratore: la seguente &egrave; la lista delle Enciclopedie inattive:");
define("_NORESULTSTEXT","Nessun risultato nel testo dei termini...");
define("_NORESULTSTITLE","Nessun risultato nel titolo dei termini...");
define("_SEARCHRESULTSFOR","Risultati Ricerca per:");
define("_SEARCHNOTCOMPLETE","Le opzioni di ricerca non sono complete. Per favore, riprova.");
define("_RESULTSINTERMTITLE","Risultati nel titolo dei termini:");
define("_RESULTSINTERMTEXT","Risultati nel testo dei termini:");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-italian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pagina Precedente");
define("_NEXT","Prossima Pagina");
define("_SEARCHRESULTS","Risultati Ricerca");
define("_PAGE","Pagina");
define("_RETURNTO","Ritorna a");
define("_DEACTIVATE","Disattiva");
define("_ACTIVATE","Attiva");
define("_ENCYCLOPEDIA","Enciclopedia");
define("_NOCONTENTFORLETTER","Non ci sono occorrenze per la lettera");
define("_ENCYSELECTLETTER","Seleziona una lettera da questa lista per consultare i termini:");
define("_COPYRIGHT","Copyright &copy; by $sitename. Tutti i diritti riseervati.");
define("_YOURADMINENCY","Sei l'amministratore, questa Enciclopedia non &egrave; attiva!");
define("_ENCYNOTACTIVE","Spiacente, questa enciclopedia non &egrave; attiva al momento.");
define("_AVAILABLEENCYLIST","Lista delle Enciclopedie disponibili in");
define("_YOURADMININACTIVELIST","Sei l'amministratore: la seguente &egrave; la lista delle Enciclopedie inattive:");
define("_NORESULTSTEXT","Nessun risultato nel testo dei termini...");
define("_NORESULTSTITLE","Nessun risultato nel titolo dei termini...");
define("_SEARCHRESULTSFOR","Risultati Ricerca per:");
define("_SEARCHNOTCOMPLETE","Le opzioni di ricerca non sono complete. Per favore, riprova.");
define("_RESULTSINTERMTITLE","Risultati nel titolo dei termini:");
define("_RESULTSINTERMTEXT","Risultati nel testo dei termini:");

?>
